@@ -1,4 +1,4 @@
-! WHIZARD 2.2.5 Feb 27 2015
+! WHIZARD 2.2.6 May 02 2015
 ! 
 ! Copyright (C) 1999-2015 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -256,14 +256,14 @@ contains
              qn_hel(2:2) = it_hel2%get_quantum_numbers ()
              qn_hel(4:4) = it_hel2%get_quantum_numbers ()
              qn = qn_hel .merge. qn_fc
-             call interaction_add_state (sf_int%interaction_t, qn)
+             call sf_int%add_state (qn)
              call it_hel2%advance ()
           end do
           call polarization_final (pol2)
           call it_hel1%advance ()
        end do
        call polarization_final (pol2)
-       call interaction_freeze (sf_int%interaction_t)
+       call sf_int%freeze ()
        call sf_int%set_incoming ([1,2])
        call sf_int%set_outgoing ([3,4])
        call sf_int%data%open ()
@@ -274,7 +274,7 @@ contains
   subroutine sf_beam_events_final (object)
     class(beam_events_t), intent(inout) :: object
     call object%data%close ()
-    call interaction_final (object%interaction_t)
+    call object%interaction_t%final ()
   end subroutine sf_beam_events_final
 
   function beam_events_is_generator (sf_int) result (flag)
@@ -363,8 +363,7 @@ contains
     real(default), intent(in) :: scale
     real(default) :: f
     f = 1
-    call interaction_set_matrix_element (sf_int%interaction_t, &
-         cmplx (f, kind=default))        
+    call sf_int%set_matrix_element (cmplx (f, kind=default))        
     sf_int%status = SF_EVALUATED
   end subroutine beam_events_apply
 
