@@ -29,22 +29,26 @@ subroutine init_external_parameters (par) bind (C)
   implicit none
 
   real(c_default_float), dimension(*), intent(inout) :: par
-  real(default) :: m1s_in, wtop, alphas, mZ, &
-                   nloop, sh, sf, match, mpole, &
-                   alphaemi, sw, mW, mb
+  real(default) :: m1s, Vtb, wt_inv, alphas, mZ, &
+                   nloop, sh, sf, FF, v1, v2, match, mpole, &
+                   aemi, sw, mW, mb, wtop
   mZ     = par(1)
   mW     = par(2)
   alphas = par(4)
   mb     = par(10)
-  alphaemi = par(19)
-  m1s_in = par(20)
-  wtop   = par(21)
-  nloop  = par(22)
-  sh     = par(23)
-  sf     = par(24)
-  sw     = par(28)
-  call ttv_formfactors_init (mpole, m1s_in, wtop, alphaemi, sw, alphas, &
-                mZ, mW, mb, sh, sf, nloop)
-  par(21) = wtop
-  par(30) = mpole
+  aemi   = par(19)
+  m1s    = par(20)
+  Vtb    = par(21)
+  wt_inv = par(22)
+  nloop  = par(23)
+  sh     = par(24)
+  sf     = par(25)
+  FF     = par(26)
+  v1     = par(27)
+  v2     = par(28)
+  sw     = par(32)
+  call ttv_formfactors_init_parameters (mpole, wtop, m1s, Vtb, wt_inv, aemi, &
+                        sw, alphas, mZ, mW, mb, sh, sf, nloop, FF, v1, v2)
+  par(34) = mpole
+  par(35) = wtop
 end subroutine init_external_parameters
